@@ -1085,6 +1085,12 @@ void qpwgraph_main::helpAbout (void)
 	text += tr("Using: Qt %1").arg(qVersion());
 #if defined(QT_STATIC)
 	text += "-static";
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+	text += ' ';
+	text += '(';
+	text += QApplication::platformName();
+	text += ')';
 #endif
 	text += ", ";
 	text +=	tr("PipeWire %1 (headers: %2)")
@@ -1970,6 +1976,13 @@ void qpwgraph_main::closeQuit (void)
 // Session management handler (eg. logoff)
 void qpwgraph_main::commitData ( QSessionManager& sm )
 {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+	QStringList args;
+	args << QApplication::applicationName();
+	args << "-platform" << QApplication::platformName();
+	args << "-session" << sm.sessionId();
+	sm.setRestartCommand(args);
+#endif
 	sm.release();
 
 	m_config->setSessionStartMinimized(!isVisible() && !isMinimized());
